aboutsummaryrefslogtreecommitdiffstats
path: root/lib/pama/models
diff options
context:
space:
mode:
Diffstat (limited to 'lib/pama/models')
-rw-r--r--lib/pama/models/models.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/pama/models/models.go b/lib/pama/models/models.go
index 9b21f0f5..5d1a9c44 100644
--- a/lib/pama/models/models.go
+++ b/lib/pama/models/models.go
@@ -70,9 +70,9 @@ type RevisionController interface {
Author(string) string
// Date returns the date for the provided commit hash.
Date(string) string
// Remove removes the commit with the provided commit hash from the
// repository.
- Remove(string) error
+ Drop(string) error
// ApplyCmd returns a string with an executable command that is used to
// apply patches with the :pipe command.
ApplyCmd() string
@@ -70,9 +70,9 @@ type RevisionController interface {
// Date returns the date for the provided commit hash.
Date(string) string
- // Remove removes the commit with the provided commit hash from the
+ // Drop removes the commit with the provided commit hash from the
// repository.